
FilFinder
=========

The entire algorithm is run through `fil_finder_2D`. Nominally, this is the only portion of the package that needs to be accessed for users.

Filament profiles can be extracted using the `width_profiles` module.

Source Code
-----------
.. automodapi:: fil_finder
    :no-heading:
    :no-inheritance-diagram:
